@@ -20,9 +20,9 @@ public class Version {
 	private Version(){}
 	/**
 	 * Paraseleneのバージョン番号を表す文字列。
-	 * 2.2.2
+	 * 2.2.2.5
 	 */
-	public static final String VERSION = "2.2.2";
+	public static final String VERSION = "2.2.2.5";
 	private static final String	SITE = " (http://paraselene.sourceforge.jp/)";
 	private static final String	TITLE = "Paraselene2 " + VERSION + SITE;
 	private static final String[] CLASS_PATH = new String[] {
@@ -102,8 +102,11 @@ public class Version {
 	private static File seekJar() {
 		try {
 			URL	url = Version.class.getResource( "/paraselene/Version.class" );
-			URI	uri = new URI( url.toString().split( "!" )[0].substring( 4 ) );
+			String	path = URIValue.encode( url.toString().split( "!" )[0].substring( 4 ), null, false );
+			URI	uri = new URI( path );
 			File	file = new File( uri );
+			path = URLDecoder.decode( file.getPath(), URIValue.DEFAULT_ENC );
+			file = new File( path );
 			return file;
 		}
 		catch( Exception e ) {
