@@ -26,25 +26,44 @@ public class TagData implements Serializable {
 		this( tag, true );
 	}
 
-	TagData( Tag tag, boolean flag ) {
-		this.id = tag.getAttributeToString( "id" );
+	private void init( Tag tag ) {
 		Page	page = tag.getAssignedPage();
-		if ( flag ) {
-			if ( SandBox.isCurrentDaemon() ) {
-				PageHooker[]	hook = tag.getInnerHTMLPart( page.getPageHooker() );
-				for ( int i = 0; i < hook.length; i++ ) {
-					hook[i].commitDaemon();
+		if ( SandBox.isCurrentDaemon() ) {
+			PageHooker[]	org = page.getPageHooker();
+			PageHooker[]	hook = tag.getInnerHTMLPart( org );
+			for ( int i = 0; i < hook.length; i++ ) {
+				hook[i].commitDaemon();
+			}
+			for ( int i = 0; i < org.length; i++ ) {
+				if ( org[i] instanceof PageBypassedDiv ) {
+					org[i].commitDaemon();
 				}
 			}
-			int cnt = tag.getHTMLPartCount();
-			JsonWriter	w = new JsonWriter();
-			for ( int i = 0; i < cnt; i++ ) {
-				tag.getHTMLPart( i ).write( w, HTMLPart.StringMode.BODY );
-			}
-			body = w.toString();
-			cmd = new String[]{ page.getOnLoadScript() };
-			page.resetOnLoadScript();
+		}
+		int cnt = tag.getHTMLPartCount();
+		JsonWriter	w = new JsonWriter();
+		for ( int i = 0; i < cnt; i++ ) {
+			tag.getHTMLPart( i ).write( w, HTMLPart.StringMode.BODY );
+		}
+		body = w.toString();
+		page = page.getParentPage();
+		cmd = new String[]{ page.getOnLoadScript() };
+		page.resetOnLoadScript();
+		tag.resetModify();
+	}
+
+	TagData( Tag tag, boolean flag ) {
+		this.id = tag.getAttributeToString( "id" );
+		if ( tag instanceof PageBypassedDiv ) {
 			tag.resetModify();
+			PageBypassedDiv	div = (PageBypassedDiv)tag;
+			Page	page = div.getViewPage();
+			if ( page == null )	return;
+			tag = page.getBodyTag();
+			if ( tag == null )	return;
+		}
+		if ( flag ) {
+			init( tag );
 		}
 	}
 
@@ -63,7 +82,7 @@ public class TagData implements Serializable {
 			}
 		}
 		else {
-			TagData	td = new TagData( out.getFirstTagByType( "body" ) );
+			TagData	td = new TagData( out.getBodyTag() );
 			td.id = org.getRootID();
 			list.add( td );
 		}
