@@ -165,11 +165,11 @@ public class RequestParameter implements Serializable {
 	private URI	uri = null;
 	private URI	sub_uri = null;
 	private String	context_path = null;
-	private HttpSession	session = null;
-	private Cookie[]	in_cookie = null;
+	private transient HttpSession	session = null;
+	private transient Cookie[]	in_cookie = null;
 	private String	remote_addr = null;
 	private HashMap<String,String[]>	header = new HashMap<String,String[]>();
-	private Supervisor	supervisor = null;
+	private transient Supervisor	supervisor = null;
 	static final String UA_HEAD = "User-Agent";
 
 	private static final String	AJAX_CALLED = "paraselene$ajax$called";
