@@ -104,7 +104,7 @@ public class Button extends Input implements PageHooker, Clickable {
 
 	public void commitDaemon() {
 		StringBuilder	buf = new StringBuilder( "function(ev){" );
-		buf = buf.append( "paraselene_form_kill=" );
+		buf = buf.append( "paraselene.form_kill=" );
 		buf = buf.append( isAjaxEnable()?	"false":	"true" );
 		buf = buf.append( ";}" );
 		setAnonymousEventHandler( "click", buf.toString() );
