@@ -11,13 +11,15 @@ import java.io.*;
 import java.net.*;
 import paraselene.*;
 import paraselene.tag.*;
+import paraselene.ui.*;
+import paraselene.supervisor.*;
 
 
 /**
  * １行テキストボックス。<br>
  * パスワード入力用ボックスであれば、ブラウザへvalueを返しません。
  */
-public class SingleTextBox extends Input {
+public class SingleTextBox extends Input implements PageHooker {
 	private static final long serialVersionUID = 2L;
 	private boolean password_f = false;
 	private boolean hidden_f = false;
@@ -102,6 +104,38 @@ public class SingleTextBox extends Input {
 	public void trim() {
 		trim( this );
 	}
+
+	private boolean enter_kill_f = true;
+
+	/**
+	 * エンターキー無効指定。デフォルト状態は無効です。
+	 * ただし、エンターキー無効機能は Ajax 有効時でしか機能しません。
+	 * @param flag true:無効、false:有効(エンターキーでsubmitする)。
+	 */
+	public void setDisableEnter( boolean flag ) {
+		enter_kill_f = flag;
+		setModify();
+	}
+	/**
+	 * エンターキー無効状態取得。
+	 * ただし、エンターキー無効機能は Ajax 有効時でしか機能しません。
+	 * @return true:無効、false:有効(エンターキーでsubmitする)。
+	 */
+	public boolean isDisableEnter() {
+		return enter_kill_f;
+	}
+
+	public Forward beforeInput( Page page, RequestParameter req, Forward fw ) throws Exception {
+		return fw;
+	}
+	public void afterOutput( Page from, Page to, RequestParameter req ) throws Exception {
+		commitDaemon();
+	}
+	public void commitDaemon() {
+		if ( isDisableEnter() ) {
+			setEventHandler( "keypress", "paraselene.kill_enter" );
+		}
+	}
 }
 
 
